@@ -1,5 +1,5 @@
 package Selenium::Subclass;
-$Selenium::Subclass::VERSION = '2.00';
+$Selenium::Subclass::VERSION = '2.01';
 #ABSTRACT: Generic template for Selenium sugar subclasses like Selenium::Session
 
 use strict;
@@ -97,7 +97,7 @@ Selenium::Subclass - Generic template for Selenium sugar subclasses like Seleniu
 
 =head1 VERSION
 
-version 2.00
+version 2.01
 
 =head1 CONSTRUCTOR
 
@@ -105,16 +105,58 @@ version 2.00
 
 You should probably not use this directly; objects should be created as part of normal operation.
 
-=head1 AUTHOR
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Selenium::Client|Selenium::Client>
+
+=back
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/troglodyne-internet-widgets/selenium-client-perl/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 AUTHORS
+
+Current Maintainers:
+
+=over 4
+
+=item *
 
 George S. Baugh <george@troglodyne.net>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2023 by George S. Baugh.
+Copyright (c) 2024 Troglodyne LLC
 
-This is free software, licensed under:
 
-  The MIT (X11) License
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
 
 =cut
